summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/jpeglossless/actionthread.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kipi-plugins/jpeglossless/actionthread.cpp')
-rw-r--r--kipi-plugins/jpeglossless/actionthread.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kipi-plugins/jpeglossless/actionthread.cpp b/kipi-plugins/jpeglossless/actionthread.cpp
index 60dd745..f21f410 100644
--- a/kipi-plugins/jpeglossless/actionthread.cpp
+++ b/kipi-plugins/jpeglossless/actionthread.cpp
@@ -12,7 +12,7 @@
* Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
*
* NOTE: Do not use kdDebug() in this implementation because
* it will be multithreaded. Use qDebug() instead.
* See B.K.O #133026 for details.
*
* This program is free software; you can redistribute it
@@ -224,7 +224,7 @@ void ActionThread::run()
}
default:
{
- qDebug("KIPIJPEGLossLessPlugin:ActionThread: "
+ tqDebug("KIPIJPEGLossLessPlugin:ActionThread: "
"Unknown action specified");
delete d;
}
@@ -12,7 +12,7 @@
*
* NOTE: Do not use kdDebug() in this implementation because
- * it will be multithreaded. Use qDebug() instead.
+ * it will be multithreaded. Use tqDebug() instead.
* See B.K.O #133026 for details.
*